RequestData class
Constructors
-
RequestData({Map<
String, dynamic> ? body, RequestFileData? file, String? rawJson})
Properties
-
body
↔ Map<
String, dynamic> ? -
getter/setter pair
- file ↔ RequestFileData?
-
only used for type POST request
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- rawJson ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited